#!/usr/bin/env bash

# Copyright 2018- The Pixie Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0

# Script that converts the certs generated by lego into yaml files.
if [ $# -ne 2 ]; then
  echo "Expected 2 Arguments: CERTSDIR and OUTCERTS. Received $#."
  exit 1
fi
CERTSDIR=$1
OUTCERTS=$2

workspace=$(bazel info workspace 2> /dev/null)

package_and_encrypt_certs(){
  if [ $# -ne 2 ]; then
    echo "Expected 2 Arguments: TYPE and ADDRESS. Received $#."
    exit 1
  fi

  TYPE=$1
  ADDRESS=$2
  PARENTPATH=${OUTCERTS}/${TYPE}
  OUTFILE_UNENC=${PARENTPATH}/certs_unenc.yaml
  OUTFILE_ENC=${PARENTPATH}/certs.yaml
  python "${workspace}"/src/cloud/dnsmgr/scripts/assemble_cert_yaml.py "${CERTSDIR}" "${ADDRESS}" "${OUTFILE_UNENC}"
  sops --config="${workspace}"/credentials/.sops.yaml --encrypt "${OUTFILE_UNENC}" >> "${OUTFILE_ENC}"
  rm "${OUTFILE_UNENC}"
}

package_and_encrypt_certs "dev" "clusters.dev.withpixie.dev"
package_and_encrypt_certs "staging" "clusters.staging.withpixie.dev"
package_and_encrypt_certs "prod" "clusters.withpixie.ai"
